Asphalt-templating documentation
================================

Asphalt-templating provides a common interface for several template rendering libraries.

.. toctree::
   :maxdepth: 1

   configuration
   usage
   extending
   versionhistory


Indices and tables
==================

* :ref:`API reference <modindex>`
